@@ -156,6 +156,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Lektor",
     "Framework :: Masonite",
     "Framework :: Matplotlib",
+    "Framework :: MkDocs",
     "Framework :: Nengo",
     "Framework :: Odoo",
     "Framework :: Odoo :: 8.0",
@@ -167,6 +168,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Odoo :: 14.0",
     "Framework :: Odoo :: 15.0",
     "Framework :: Odoo :: 16.0",
+    "Framework :: Odoo :: 17.0",
     "Framework :: Opps",
     "Framework :: Paste",
     "Framework :: Pelican",
@@ -189,6 +191,9 @@ sorted_classifiers: List[str] = [
     "Framework :: Plone :: Core",
     "Framework :: Plone :: Distribution",
     "Framework :: Plone :: Theme",
+    "Framework :: PySimpleGUI",
+    "Framework :: PySimpleGUI :: 4",
+    "Framework :: PySimpleGUI :: 5",
     "Framework :: Pycsou",
     "Framework :: Pydantic",
     "Framework :: Pydantic :: 1",
@@ -452,6 +457,7 @@ sorted_classifiers: List[str] = [
     "Programming Language :: F#",
     "Programming Language :: Forth",
     "Programming Language :: Fortran",
+    "Programming Language :: Go",
     "Programming Language :: Haskell",
     "Programming Language :: Java",
     "Programming Language :: JavaScript",
